@@ -4,12 +4,13 @@ pub mod output;
 pub mod utils;
 
 use clap::Parser;
+use colored::control::{ShouldColorize, SHOULD_COLORIZE};
 use consts::COMMAND_MARKER;
-use melody_compiler::{compiler, ParseError};
+use melody_compiler::{compiler, errors::ParseError};
 use output::{
-    print_output, print_output_pretty, print_repl_welcome, print_source_line, prompt, report_clear,
-    report_exit, report_missing_path, report_no_lines_to_print, report_nothing_to_redo,
-    report_nothing_to_undo, report_parse_error, report_read_file_error, report_redo,
+    print_output, print_repl_welcome, print_source_line, prompt, report_clear, report_exit,
+    report_missing_path, report_no_lines_to_print, report_nothing_to_redo, report_nothing_to_undo,
+    report_parse_error, report_read_file_error, report_read_input_error, report_redo,
     report_repl_parse_error, report_source, report_undo, report_unrecognized_command,
     report_write_file_error,
 };
@@ -39,9 +40,12 @@ enum CliError {
     ReadFileError(String),
     ParseError(ParseError),
     WriteFileError(String),
+    ReadInputError,
 }
 
 fn main() {
+    ShouldColorize::from_env();
+
     match cli() {
         Ok(_) => exit(ExitCode::Ok),
         Err(error) => {
@@ -51,11 +55,8 @@ fn main() {
                 CliError::WriteFileError(output_file_path) => {
                     report_write_file_error(output_file_path)
                 }
-                CliError::ParseError(parse_error) => report_parse_error(
-                    parse_error.token,
-                    parse_error.line,
-                    parse_error.line_index + 1,
-                ),
+                CliError::ParseError(parse_error) => report_parse_error(parse_error.message),
+                CliError::ReadInputError => report_read_input_error(),
             }
             exit(ExitCode::Error)
         }
@@ -72,6 +73,10 @@ fn cli() -> Result<(), CliError> {
         no_color_output,
     } = args;
 
+    if no_color_output {
+        SHOULD_COLORIZE.set_override(false);
+    }
+
     if start_repl {
         return repl();
     }
@@ -89,11 +94,7 @@ fn cli() -> Result<(), CliError> {
                 .map_err(|_| CliError::WriteFileError(output_file_path))?;
         }
         None => {
-            if no_color_output {
-                print_output(compiler_output);
-            } else {
-                print_output_pretty(compiler_output);
-            }
+            print_output(compiler_output);
         }
     }
 
@@ -109,7 +110,7 @@ fn repl() -> Result<(), CliError> {
     'repl: loop {
         prompt();
 
-        let input = read_input();
+        let input = read_input().map_err(|_| CliError::ReadInputError)?;
 
         if input.starts_with(COMMAND_MARKER) {
             match input.as_str() {
@@ -123,11 +124,11 @@ fn repl() -> Result<(), CliError> {
                         redo_lines.push(latest);
 
                         if !valid_lines.is_empty() {
-                            let source = &valid_lines.join("");
+                            let source = &valid_lines.join("\n");
                             let raw_output = compiler(source);
                             let output = raw_output.unwrap();
 
-                            print_output_pretty(format!("{output}\n"));
+                            print_output(format!("{output}\n"));
                         }
                     }
                 }
@@ -140,11 +141,11 @@ fn repl() -> Result<(), CliError> {
                         let latest = redo_lines.pop().unwrap();
                         valid_lines.push(latest);
 
-                        let source = &valid_lines.join("");
+                        let source = &valid_lines.join("\n");
                         let raw_output = compiler(source);
                         let output = raw_output.unwrap();
 
-                        print_output_pretty(format!("{output}\n"));
+                        print_output(format!("{output}\n"));
                     }
                 }
                 format_command!("s", "source") => {
@@ -178,28 +179,24 @@ fn repl() -> Result<(), CliError> {
         }
 
         if input.is_empty() {
-            let source = &valid_lines.join("");
+            let source = &valid_lines.join("\n");
             let raw_output = compiler(source);
             let output = raw_output.unwrap();
 
-            print_output_pretty(format!("{output}\n"));
+            print_output(format!("{output}\n"));
 
             continue 'repl;
         }
 
         valid_lines.push(input);
 
-        let source = &valid_lines.join("");
+        let source = &valid_lines.join("\n");
         let raw_output = compiler(source);
 
         if let Err(error) = raw_output {
-            let ParseError {
-                token,
-                line: _,
-                line_index: _,
-            } = error;
+            let ParseError { message } = error;
 
-            report_repl_parse_error(token);
+            report_repl_parse_error(message);
 
             valid_lines.pop();
 
@@ -210,6 +207,6 @@ fn repl() -> Result<(), CliError> {
 
         let output = raw_output.unwrap();
 
-        print_output_pretty(format!("{output}\n"))
+        print_output(format!("{output}\n"))
     }
 }
